"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MyEditor = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const slate_1 = require("slate");
const slate_react_1 = require("slate-react");
const react_1 = require("react");
const src_1 = require("../src");
const slate_history_1 = require("slate-history");
const render_element_1 = require("./render-element");
const image_block_1 = require("../src/components/image-block");
const image_inline_1 = require("../src/components/image-inline");
const titled_image_block_1 = require("../src/components/titled-image-block");
const attachment_block_1 = require("../src/components/attachment-block");
const delay_1 = __importDefault(require("delay"));
require("./types");
function MyEditor({ apiKey, authToken, apiOriginUrl, initialValue, initialOrigins = {}, isReadOnly, }) {
    const [editor] = (0, react_1.useState)(() => {
        const reactEditor = (0, slate_react_1.withReact)((0, slate_history_1.withHistory)((0, slate_1.createEditor)()));
        const editor = (0, src_1.withCloud)(reactEditor, {
            apiKey,
            authToken,
            apiOriginUrl,
            minResizeWidth: 100,
            maxResizeWidth: 640,
            initialOrigins,
        });
        attachment_block_1.AttachmentBlock.withEditor(editor);
        image_inline_1.ImageInline.withEditor(editor);
        titled_image_block_1.TitledImageBlock.withEditor(editor);
        image_block_1.ImageBlock.withEditor(editor);
        return editor;
    });
    const [saveState, setSaveState] = (0, react_1.useState)("ready");
    const save = (0, react_1.useCallback)(async () => {
        setSaveState("saving");
        console.log("children", editor.children);
        const result = await editor.cloud.save({ maxTimeoutInMs: 1000 });
        console.log("value", result.value);
        setSaveState("saved");
        await (0, delay_1.default)(1000);
        setSaveState("ready");
    }, [editor]);
    return ((0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsxs)("p", { children: [(0, jsx_runtime_1.jsx)("button", { onClick: save, children: "Save Document" }), " ", (0, jsx_runtime_1.jsxs)("span", { style: { font: "12px sans-serif" }, children: [saveState === "saving" ? "Saving" : null, saveState === "saved" ? "Saved! Document value in console" : null] })] }), (0, jsx_runtime_1.jsx)("p", { children: (0, jsx_runtime_1.jsx)("input", { type: "file", onChange: editor.cloud.handleInputFileChange, multiple: true }) })] }), (0, jsx_runtime_1.jsx)(slate_react_1.Slate, { editor: editor, value: initialValue, children: (0, jsx_runtime_1.jsx)(slate_react_1.Editable, { readOnly: isReadOnly, renderElement: render_element_1.renderElement, onPaste: editor.cloud.handlePaste, onDrop: editor.cloud.handleDrop, style: {
                        font: "16px sans-serif",
                        border: "1px solid #c0c0c0",
                        borderRadius: 8,
                        padding: "0 16px",
                        width: 480,
                    } }) })] }));
}
exports.MyEditor = MyEditor;
