"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AttachmentBlock = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const render_attachment_block_1 = require("./render-attachment-block");
const transforms_1 = require("../../transforms");
const ELEMENT_TYPE = "attachment-block";
/**
 * Augment `Editor` to support this element type
 */
function withEditor(editor) {
    const { cloud } = editor;
    /**
     * override `isVoid`
     */
    const originalIsVoid = editor.isVoid;
    editor.isVoid = (element) => {
        return element.type === ELEMENT_TYPE ? true : originalIsVoid(element);
    };
    /**
     * override `onUpload`
     */
    cloud.onUpload = (e) => {
        (0, transforms_1.insertBlock)(editor, {
            type: "attachment-block",
            id: e.id,
            filename: e.file.name,
            bytes: e.file.size,
            children: [{ text: "" }],
        });
    };
    return editor;
}
/**
 * Augment `renderElement` method to support this element type
 */
function withRenderElement(renderElement) {
    const originalRenderElement = renderElement;
    return function renderElement(props) {
        if (props.element.type !== ELEMENT_TYPE)
            return originalRenderElement(props);
        return (0, jsx_runtime_1.jsx)(render_attachment_block_1.AttachmentBlock, { ...props, element: props.element });
    };
}
exports.AttachmentBlock = {
    ELEMENT_TYPE,
    Element: render_attachment_block_1.AttachmentBlock,
    withEditor,
    withRenderElement,
};
