"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleInputFileChange = exports.handleDropFile = exports.handlePasteFile = void 0;
const slate_1 = require("slate");
const slate_react_1 = require("slate-react");
/**
 * Handle uploading of files
 */
function uploadFiles(editor, files) {
    if (files == null || files.length === 0)
        return false;
    /**
     * If there is no selection when this is called, we need somewhere for the
     * file to go so we select the start of the editor as a default.
     */
    if (editor.selection == null) {
        slate_1.Transforms.select(editor, slate_1.Editor.start(editor, [0]));
    }
    for (const file of [...files].reverse()) {
        editor.cloud.uploadFile(file);
    }
    return true;
}
/**
 * handle `pasteFile` on any Element
 */
const handlePasteFile = (editor, e) => {
    const files = e.clipboardData.files;
    if (files.length === 0)
        return false;
    uploadFiles(editor, files);
    e.preventDefault();
    e.stopPropagation();
    return true;
};
exports.handlePasteFile = handlePasteFile;
/**
 * handle `dropFile` on any Element
 */
const handleDropFile = (editor, e) => {
    const files = e.dataTransfer.files;
    if (files.length === 0)
        return false;
    /**
     * When we drop a file, the selection won't move automatically to the drop
     * location. Find the location from the event and upload the files at that
     * location.
     */
    const at = slate_react_1.ReactEditor.findEventRange(editor, e);
    slate_1.Transforms.select(editor, at);
    uploadFiles(editor, files);
    e.preventDefault();
    e.stopPropagation();
    return true;
};
exports.handleDropFile = handleDropFile;
/**
 * handle `onChange` on any `<input type="file" />` Element
 */
const handleInputFileChange = (editor, e) => {
    const files = e.target.files;
    return uploadFiles(editor, files);
};
exports.handleInputFileChange = handleInputFileChange;
