"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withCloud = void 0;
const upload_store_1 = require("./upload-store");
const upload_file_1 = require("./upload-file");
const upload_handlers_1 = require("./upload-handlers");
const save_1 = require("../save");
const get_origins_1 = require("../save/get-origins");
const client_1 = require("@portive/client");
function withCloud(editor, { apiOriginUrl, apiKey, authToken, 
// images can only be resized as low as this value.
// If the source image is less than this number, it cannot be resized
minResizeWidth = 100, maxResizeWidth = 1280, initialMaxSize = { width: 320, height: 320 }, initialOrigins = {}, onUpload = () => {
    /* noop */
}, }) {
    const useStore = (0, upload_store_1.createUploadStore)({ origins: initialOrigins });
    /**
     * Create an instance of the Portive Client
     */
    const client = new client_1.Client({ apiKey, authToken, apiOrigin: apiOriginUrl });
    editor.cloud = {
        client,
        minResizeWidth,
        maxResizeWidth,
        initialMaxSize,
        useStore,
        /**
         * Call this to initiate a file upload
         */
        uploadFile(file) {
            return (0, upload_file_1.upload)(editor, file);
        },
        /**
         * Use this in `Editable` as the `onDrop` event handler.
         * Returns `true` if the drop was handled.
         */
        handleDrop(e) {
            return (0, upload_handlers_1.handleDropFile)(editor, e);
        },
        /**
         * Use this in `Editable` as the `onPaste` event handler.
         * Returns `true` if the paste was handled.
         */
        handlePaste(e) {
            return (0, upload_handlers_1.handlePasteFile)(editor, e);
        },
        /**
         * Use this on an `<input type="file" />` as the `onChange` event handler.
         * Returns `true` if files were present in the Input Element and the
         * upload process was started.
         */
        handleInputFileChange(e) {
            return (0, upload_handlers_1.handleInputFileChange)(editor, e);
        },
        /**
         * Waits for the files to finish uploading.
         *
         * If files finish uploading returns:
         * { status: "complete", value: Descendant[] }
         *
         * If we hit the timeout, we remove unfinished uploads and return:
         * { status: "timeout", value: Descendant[] }
         */
        async save(options = {}) {
            return await (0, save_1.save)(editor, options);
        },
        normalize() {
            const origins = (0, get_origins_1.getOrigins)(editor);
            return (0, save_1.normalizeOrigins)(editor.children, origins);
        },
        onUpload,
    };
    return editor;
}
exports.withCloud = withCloud;
