import { ImageFileInterface, Upload } from "../types";
import { CSSProperties } from "react";
import { RenderElementPropsFor } from "../types/type-utils";
export * from "./status-bar";
export declare function RenderHostedImage({ attributes, element, children, }: RenderElementPropsFor<ImageFileInterface>): JSX.Element;
/**
 * Adds a `boxShadow` around the Element when it is selected.
 */
export declare function useHighlightedStyle(): {
    boxShadow: string;
};
/**
 * Takes an `element` (which it only needs for its `id`) and returns the
 * Upload object from it.
 */
export declare function useUpload(id: string): Upload;
/**
 * Strategy for handling `maxSize`
 *
 * How to handle maxSize.
 *
 * When an image is first uploaded, the size is taken from the `Image` object.
 *
 * This size can be persisted to the `Element` but then it has to be saved
 * which is unnecessary since it can be derived from the `url`.
 *
 * Saving it as a separate prop also has problems in that the maxSize could be
 * changed and puts the `Element` in an inconsistent state. But this invalid
 * state would be unlikely and we could also fix it with a normalizer to be
 * safe.
 *
 * Another method is to to add `maxSize` to `useHostedImage` as part of the
 * `HostImageContext`. In this scenario, we either get the `maxSize` from the
 * `url` if it is valid, or we get it from the `Origin` if it is not.
 *
 * We could prefer the `maxSize` from the `url` and if that fails, then we
 * fall back to the `Origin`.
 *
 * # Saving
 *
 * We should also make saving through a method like `editor.getHostedChildren()`
 * which returns `Promise`.
 */
declare type ImageProps = React.HTMLAttributes<HTMLImageElement>;
export declare function HostedImage({ element, className, style, ...imageProps }: {
    element: ImageFileInterface;
    className?: string;
    style?: CSSProperties;
} & ImageProps): JSX.Element;
