"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HostedImage = exports.useUpload = exports.useHighlightedStyle = exports.RenderHostedImage = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const slate_react_1 = require("slate-react");
const image_controls_1 = require("./image-controls");
const react_1 = require("react");
const hosted_image_context_1 = require("./hosted-image-context");
__exportStar(require("./status-bar"), exports);
function RenderHostedImage({ attributes, element, children, }) {
    return ((0, jsx_runtime_1.jsxs)("div", { ...attributes, style: { margin: "8px 0" }, children: [(0, jsx_runtime_1.jsx)(HostedImage, { element: element, style: { borderRadius: element.width < 100 ? 0 : 4 } }), children] }));
}
exports.RenderHostedImage = RenderHostedImage;
/**
 * Adds a `boxShadow` around the Element when it is selected.
 */
function useHighlightedStyle() {
    const selected = (0, slate_react_1.useSelected)();
    const focused = (0, slate_react_1.useFocused)();
    const highlighted = selected && focused;
    const boxShadow = highlighted ? "0 0 0 3px DodgerBlue" : "none";
    return { boxShadow };
}
exports.useHighlightedStyle = useHighlightedStyle;
/**
 * Takes an `element` (which it only needs for its `id`) and returns the
 * Upload object from it.
 */
function useUpload(id) {
    const editor = (0, slate_react_1.useSlateStatic)();
    /**
     * We call this even if it's not always required because it calls `useStore`
     * which is a React hook which means it needs to be called consistently.
     */
    const upload = editor.cloud.useStore((state) => state.uploads[id]);
    if (id.includes("/")) {
        return {
            status: "complete",
            url: id,
        };
    }
    else {
        return upload;
    }
}
exports.useUpload = useUpload;
// function getSizeFromElement(): {width: number, height: number} {
// }
function HostedImage({ element, className, style, ...imageProps }) {
    const editor = (0, slate_react_1.useSlateStatic)();
    const upload = useUpload(element.id);
    const [size, setSize] = (0, react_1.useState)({
        width: element.width,
        height: element.height,
    });
    (0, react_1.useEffect)(() => {
        setSize({ width: element.width, height: element.height });
    }, [element.width, element.height]);
    const highlightedStyle = useHighlightedStyle();
    const src = generateSrc({
        originUrl: upload.url,
        size: [element.width, element.height],
        maxSize: [element.maxWidth, element.maxHeight],
        isAnimated: element.isAnimated,
    });
    const srcSet = generateSrcSet({
        originUrl: upload.url,
        size: [element.width, element.height],
        maxSize: [element.maxWidth, element.maxHeight],
        isAnimated: element.isAnimated,
    });
    return ((0, jsx_runtime_1.jsx)(hosted_image_context_1.HostedImageContext.Provider, { value: {
            editor,
            origin: upload,
            size,
            setSize,
        }, children: (0, jsx_runtime_1.jsx)(image_controls_1.ImageControls, { element: element, children: (0, jsx_runtime_1.jsx)("img", { src: src, srcSet: srcSet, width: size.width, height: size.height, className: className, style: { ...highlightedStyle, ...style, display: "block" }, ...imageProps }) }) }));
}
exports.HostedImage = HostedImage;
function generateSrcSet({ originUrl, size, maxSize, isAnimated, }) {
    /**
     * If it's a url from `createObjectURL` then just return it
     */
    if (originUrl.startsWith("blob:"))
        return originUrl;
    const src1x = generateSrc({
        originUrl,
        size,
        maxSize,
        isAnimated,
    });
    const src2x = generateSrc({
        originUrl,
        size: [size[0] * 2, size[1] * 2],
        maxSize,
        isAnimated,
    });
    return `${src1x}, ${src2x} 2x`;
}
function generateSrc({ originUrl, size, maxSize, isAnimated, }) {
    /**
     * If it's a url from `createObjectURL` then just return it
     */
    if (originUrl.startsWith("blob:"))
        return originUrl;
    if (isAnimated || size[0] >= maxSize[0] || size[1] >= maxSize[1])
        return originUrl;
    return `${originUrl}?size=${size[0]}x${size[1]}`;
}
