"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResizeControls = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const slate_react_1 = require("slate-react");
const slate_1 = require("slate");
const hosted_image_context_1 = require("./hosted-image-context");
const client_1 = require("@portive/client");
function ResizeControls({ element }) {
    const { size, setSize } = (0, hosted_image_context_1.useHostedImageContext)();
    const editor = (0, slate_react_1.useSlateStatic)();
    const [isResizing, setIsResizing] = (0, react_1.useState)(false);
    if (element.width < editor.cloud.minResizeWidth)
        return null;
    let currentSize = size;
    const onMouseDown = (0, react_1.useCallback)((e) => {
        setIsResizing(true);
        const startX = e.clientX;
        const startWidth = size.width;
        const minWidth = editor.cloud.minResizeWidth;
        const maxWidth = Math.min(element.maxWidth, editor.cloud.maxResizeWidth);
        /**
         * Handle resize dragging through an event handler on mouseMove on the
         * document.
         */
        function onDocumentMouseMove(e) {
            e.preventDefault();
            e.stopPropagation();
            /**
             * Calculate the proposed width based on drag position
             */
            const proposedWidth = startWidth + e.clientX - startX;
            /**
             * Constrain the proposed with between min, max and original width
             */
            const nextWidth = Math.min(maxWidth, Math.max(minWidth, proposedWidth));
            currentSize = (0, client_1.resizeInWidth)({ width: element.maxWidth, height: element.maxHeight }, nextWidth);
            setSize(currentSize);
        }
        const originalCursor = document.body.style.cursor;
        /**
         * When the user releases the mouse, remove all the event handlers
         */
        function onDocumentMouseUp() {
            setIsResizing(false);
            document.removeEventListener("mousemove", onDocumentMouseMove);
            document.removeEventListener("mouseup", onDocumentMouseUp);
            // setMode({ type: "ready" })
            document.body.style.cursor = originalCursor;
            const at = slate_react_1.ReactEditor.findPath(editor, element);
            slate_1.Transforms.setNodes(editor, { width: currentSize.width, height: currentSize.height }, { at });
        }
        /**
         * Attach document event listeners
         */
        document.addEventListener("mousemove", onDocumentMouseMove);
        document.addEventListener("mouseup", onDocumentMouseUp);
        /**
         * While dragging, we want the cursor to be `ew-resize` (left-right arrow)
         * even if the cursor happens to not be exactly on the handle at the moment
         * due to a delay in the cursor moving to a location and the image resizing
         * to it.
         *
         * Also, image has max width/height and the cursor can fall outside of it.
         */
        document.body.style.cursor = "ew-resize";
    }, [editor, size.width, size.height]);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [isResizing ? (0, jsx_runtime_1.jsx)(ResizeLabel, { size: size }) : null, (0, jsx_runtime_1.jsx)(ResizeHandles, { onMouseDown: onMouseDown })] }));
}
exports.ResizeControls = ResizeControls;
/**
 * The resize label that shows the width/height of the image
 */
function ResizeLabel({ size }) {
    const isBelow = size.width < 100 || size.height < 100;
    const bottom = isBelow ? -24 : 4;
    return ((0, jsx_runtime_1.jsxs)("div", { style: {
            position: "absolute",
            bottom,
            left: 4,
            font: "10px/20px sans-serif",
            color: "white",
            background: "#404040",
            minWidth: 50,
            padding: "0 7px",
            borderRadius: 3,
            textAlign: "center",
            boxShadow: "0px 0px 2px 1px rgba(255, 255, 255, 0.5)",
            zIndex: 100,
            transition: "bottom 250ms",
        }, children: [size.width, " \u00D7 ", size.height] }));
}
/**
 * The handle used to drag resize an image
 */
function ResizeHandles({ onMouseDown, }) {
    return ((0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: (0, jsx_runtime_1.jsx)("div", { onMouseDown: onMouseDown, style: {
                position: "absolute",
                cursor: "ew-resize",
                width: 16,
                right: -8,
                top: 0,
                bottom: 0,
                background: "rgba(127,127,127,0.01)",
            }, children: (0, jsx_runtime_1.jsxs)("div", { style: {
                    position: "absolute",
                    width: 16,
                    height: 32,
                    background: "DodgerBlue",
                    borderRadius: 4,
                    left: 0,
                    top: "50%",
                    marginTop: -16,
                }, children: [(0, jsx_runtime_1.jsx)("div", { style: { ...barStyle, left: 3.5 } }), (0, jsx_runtime_1.jsx)("div", { style: { ...barStyle, left: 7.5 } }), (0, jsx_runtime_1.jsx)("div", { style: { ...barStyle, left: 11.5 } })] }) }) }));
}
/**
 * The little divets on the resize handle bar.
 */
const barStyle = {
    position: "absolute",
    top: 8,
    width: 1,
    height: 16,
    background: "rgba(255,255,255,0.75)",
};
