import { Descendant } from "slate";
import { Upload, UploadProgress } from "../types";
/**
 * Tells us if the `id` is a `url`. If it's not, it's a lookup in the
 * origins lookup.
 */
export declare function isUrl(id: string): boolean;
/**
 * Takes an array of `nodes` and a lookup for `origins` and normalizes the
 * `nodes` such that:
 *
 * - Any node with an `id` that is a `url` is left alone
 * - Any node with an `id` that is a `key` for lookup in `origins` is
 *   converted to a `url` if the origin file has been successfully uploaded
 * - If the origin file has not been uploaded or is in an error state, then
 *   we remove that element.
 *
 * We do some typecasting here to help the Descendant values pass through.
 * We are confident this is okay because we only augment the `id` and
 * we only depend on the knowledge that `children`, if present, is an Array
 * of nodes.
 */
export declare function getUploadingOrigins(nodes: Descendant[], origins: Record<string, Upload>): UploadProgress[];
