"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.save = void 0;
const get_origins_1 = require("./get-origins");
const get_uploading_origins_1 = require("./get-uploading-origins");
const delay_1 = __importDefault(require("delay"));
const normalize_origins_1 = require("./normalize-origins");
const TEN_MINUTES = 1000 * 60 * 60;
async function save(editor, { maxTimeoutInMs = TEN_MINUTES }) {
    const origins = (0, get_origins_1.getOrigins)(editor);
    const uploadingOrigins = (0, get_uploading_origins_1.getUploadingOrigins)(editor.children, origins);
    const finishPromises = uploadingOrigins.map((origin) => origin.finishPromise);
    const timeoutPromise = (0, delay_1.default)(maxTimeoutInMs, { value: "timeout" });
    const result = await Promise.race([
        Promise.all(finishPromises),
        timeoutPromise,
    ]);
    if (result === "timeout") {
        const uploadingOrigins = (0, get_uploading_origins_1.getUploadingOrigins)(editor.children, origins);
        const finishPromises = uploadingOrigins.map((origin) => origin.finishPromise);
        return {
            status: "timeout",
            value: editor.cloud.normalize(),
            finishes: finishPromises,
        };
    }
    else {
        const origins = (0, get_origins_1.getOrigins)(editor);
        /**
         * We explicitly clear the Promise because if we don't, the timer keeps
         * on running. This is fine in the browser, but messes up unit tests with
         * this error message:
         *
         * ```
         * A worker process has failed to exit gracefully and has been force exited.
         * This is likely caused by tests leaking due to improper teardown.
         * Try running with --detectOpenHandles to find leaks.
         * Active timers can also cause this, ensure that .unref() was called on them.
         * ```
         */
        timeoutPromise.clear();
        return {
            status: "complete",
            value: (0, normalize_origins_1.normalizeOrigins)(editor.children, origins),
        };
    }
}
exports.save = save;
