import { Element } from "slate";
import { RenderElementProps } from "slate-react";
/**
 * Take one type and narrows it using a second type, usually on a type field
 * like:
 *
 * { type: "cat", ... } or { type: "dog", ... }
 *
 * This is typically referred to as a Discriminated Union in TypeScript.
 */
export declare type Discriminate<T, N> = T extends N ? T : never;
/**
 * Takes as a generic `T`, a literal string value representing the `element.type`.
 *
 * Using the value from `T`, it returns the `props` for the given Slate
 * Element which was defined using something like:
 *
 * ```typescript
 * declare module "slate" {
 *   interface CustomTypes {
 *     Element: ...
 *   }
 * }
 * ```
 */
export declare type DiscriminatedRenderElementProps<T extends Element["type"]> = Omit<RenderElementProps, "element"> & {
    element: Discriminate<Element, {
        type: T;
    }>;
};
/**
 * Generates the renderElementProps for a specific known Element which makes
 * up the prop `element` along with the other known renderEelementProps like
 * `children` and `attributes`.
 */
export declare type RenderElementPropsFor<T> = Omit<RenderElementProps, "element"> & {
    element: T;
};
