import EventEmitter from "eventemitter3";
/**
 * `Origin`
 */
export declare type OriginEventTypes = "progress" | "complete" | "error";
/**
 * Indicates an `Origin` that is uploading and the state of the Upload
 */
export declare type UploadProgress = {
    url: string;
    status: "uploading";
    sentBytes: number;
    totalBytes: number;
    eventEmitter: EventEmitter<OriginEventTypes>;
    finishPromise: Promise<Upload>;
};
/**
 * Indicates an `Origin` that has completed uploading
 */
export declare type UploadComplete = {
    url: string;
    status: "complete";
};
/**
 * Indicates an `Origin` that has an error during uploading and the Error
 * message
 */
export declare type UploadError = {
    url: string;
    status: "error";
    message: string;
};
export declare type Upload = UploadProgress | UploadComplete | UploadError;
/**
 * `OriginState`
 *
 * Types related to the `zustand` state-management library which we use to
 * store the state of uploads.
 */
export declare type GetUpload = (id: string) => Upload;
export declare type SetUpload = (id: string, upload: Upload) => void;
export declare type UploadState = {
    uploads: Record<string, Upload>;
    getUpload: GetUpload;
    setUpload: SetUpload;
};
