import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { createEditor } from "slate";
import { Slate, Editable, withReact } from "slate-react";
import { useCallback, useState } from "react";
import { withCloud } from "../src";
import { withHistory } from "slate-history";
import { renderElement } from "./render-element";
import { ImageBlock } from "../src/components/image-block";
import { ImageInline } from "../src/components/image-inline";
import { TitledImageBlock } from "../src/components/titled-image-block";
import { AttachmentBlock } from "../src/components/attachment-block";
import delay from "delay";
import "./types";
export function MyEditor({ apiKey, authToken, apiOriginUrl, initialValue, initialOrigins = {}, isReadOnly, }) {
    const [editor] = useState(() => {
        const reactEditor = withReact(withHistory(createEditor()));
        const editor = withCloud(reactEditor, {
            apiKey,
            authToken,
            apiOriginUrl,
            minResizeWidth: 100,
            maxResizeWidth: 640,
            initialOrigins,
        });
        AttachmentBlock.withEditor(editor);
        ImageInline.withEditor(editor);
        TitledImageBlock.withEditor(editor);
        ImageBlock.withEditor(editor);
        return editor;
    });
    const [saveState, setSaveState] = useState("ready");
    const save = useCallback(async () => {
        setSaveState("saving");
        console.log("children", editor.children);
        const result = await editor.cloud.save({ maxTimeoutInMs: 1000 });
        console.log("value", result.value);
        setSaveState("saved");
        await delay(1000);
        setSaveState("ready");
    }, [editor]);
    return (_jsxs("div", { children: [_jsxs("div", { children: [_jsxs("p", { children: [_jsx("button", { onClick: save, children: "Save Document" }), " ", _jsxs("span", { style: { font: "12px sans-serif" }, children: [saveState === "saving" ? "Saving" : null, saveState === "saved" ? "Saved! Document value in console" : null] })] }), _jsx("p", { children: _jsx("input", { type: "file", onChange: editor.cloud.handleInputFileChange, multiple: true }) })] }), _jsx(Slate, { editor: editor, value: initialValue, children: _jsx(Editable, { readOnly: isReadOnly, renderElement: renderElement, onPaste: editor.cloud.handlePaste, onDrop: editor.cloud.handleDrop, style: {
                        font: "16px sans-serif",
                        border: "1px solid #c0c0c0",
                        borderRadius: 8,
                        padding: "0 16px",
                        width: 480,
                    } }) })] }));
}
