import { jsx as _jsx } from "react/jsx-runtime";
import { AttachmentBlock as RenderElement } from "./render-attachment-block";
import { insertBlock } from "../../transforms";
const ELEMENT_TYPE = "attachment-block";
/**
 * Augment `Editor` to support this element type
 */
function withEditor(editor) {
    const { cloud } = editor;
    /**
     * override `isVoid`
     */
    const originalIsVoid = editor.isVoid;
    editor.isVoid = (element) => {
        return element.type === ELEMENT_TYPE ? true : originalIsVoid(element);
    };
    /**
     * override `onUpload`
     */
    cloud.onUpload = (e) => {
        insertBlock(editor, {
            type: "attachment-block",
            id: e.id,
            filename: e.file.name,
            bytes: e.file.size,
            children: [{ text: "" }],
        });
    };
    return editor;
}
/**
 * Augment `renderElement` method to support this element type
 */
function withRenderElement(renderElement) {
    const originalRenderElement = renderElement;
    return function renderElement(props) {
        if (props.element.type !== ELEMENT_TYPE)
            return originalRenderElement(props);
        return _jsx(RenderElement, { ...props, element: props.element });
    };
}
export const AttachmentBlock = {
    ELEMENT_TYPE,
    Element: RenderElement,
    withEditor,
    withRenderElement,
};
