import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Transforms } from "slate";
import { useSlateStatic } from "slate-react";
import { css } from "emotion";
import bytes from "bytes";
import { useHighlightedStyle, useUpload, StatusBar, } from "../..";
import { ReactEditor } from "slate-react";
import { useCallback } from "react";
import { DownloadIcon, FileIcon, TrashIcon } from "../../icons";
const $attachmentBlock = css `
  position: relative;
  border-radius: 0.5em;
  border: 1px solid #e0e0e0;
  margin: 8px 0;
  max-width: 360px;
  background: white;
  .--container {
    display: flex;
    gap: 0.5em;
    padding: 1em;
    align-items: center;
  }
  .--icon {
    flex: 0 0 auto;
    color: #c0c0c0;
    font-size: 1.25em;
  }
  .--icon-button {
    width: 1em;
    height: 1em;
    border-radius: 0.25em;
    padding: 0.25em;
    &:hover {
      background: #f0f0f0;
    }
  }
  .--download-icon {
    cursor: pointer;
    color: #c0c0c0;
    &:hover {
      color: black;
    }
  }
  .--trash-icon {
    cursor: pointer;
    transition: color 0.1s, background-color 0.1s;
    color: #d00000;
    background: #f8f0f0;
    &:hover {
      color: red;
      background: #ffe0e0;
    }
  }
  .--body {
    flex: 1 1 auto;
  }
  .--status-bar {
    margin-top: 0.25em;
    font-size: 0.9em;
    color: #808080;
  }
`;
export function AttachmentBlock({ attributes, element, children, }) {
    const editor = useSlateStatic();
    const upload = useUpload(element.id);
    const highlightedStyle = useHighlightedStyle();
    const removeElement = useCallback(() => {
        const at = ReactEditor.findPath(editor, element);
        Transforms.removeNodes(editor, { at });
    }, [editor, element]);
    return (_jsxs("div", { ...attributes, className: $attachmentBlock, style: highlightedStyle, children: [_jsxs("div", { className: "--container", contentEditable: false, children: [_jsx("div", { className: "--icon", children: _jsx(FileIcon, {}) }), _jsxs("div", { className: "--body", children: [_jsx("div", { children: element.filename }), _jsx(StatusBar, { upload: upload, className: "--status-bar", width: 192, height: 16, children: bytes(element.bytes) })] }), upload.status === "complete" ? (_jsx("div", { className: "--icon", children: _jsx("a", { href: upload.url, target: "_blank", rel: "noreferrer", className: "--icon-button --download-icon", download: true, children: _jsx(DownloadIcon, {}) }) })) : null, upload.status === "error" ? (_jsx("div", { className: "--icon", children: _jsx("div", { className: "--icon-button --trash-icon", onClick: removeElement, children: _jsx(TrashIcon, {}) }) })) : null] }), children] }));
}
