import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { AssertType } from "@thesunny/assert-type";
import { HostedImage, } from "../..";
import { Transforms } from "slate";
export const ELEMENT_TYPE = "image-inline";
AssertType.Extends(true);
/**
 * Augment `Editor` to support this element type
 */
function withEditor(editor) {
    const { cloud } = editor;
    /**
     * override `isVoid`
     */
    const originalIsVoid = editor.isVoid;
    editor.isVoid = (element) => {
        return element.type === ELEMENT_TYPE ? true : originalIsVoid(element);
    };
    /**
     * override `isInline`
     */
    const originalIsInline = editor.isInline;
    editor.isInline = (element) => {
        return element.type === ELEMENT_TYPE ? true : originalIsInline(element);
    };
    /**
     * override `onUpload`
     */
    const originalOnUpload = cloud.onUpload;
    cloud.onUpload = (e) => {
        if (e.type !== "image")
            return originalOnUpload(e);
        Transforms.insertNodes(editor, {
            type: "image-inline",
            id: e.id,
            width: e.initialWidth,
            height: e.initialHeight,
            maxWidth: e.maxWidth,
            maxHeight: e.maxHeight,
            isAnimated: e.isAnimated,
            children: [{ text: "" }],
        });
    };
    return editor;
}
export function Component({ attributes, element, children, }) {
    return (_jsxs("span", { ...attributes, children: [_jsx(HostedImage, { element: element, style: { borderRadius: element.width < 100 ? 0 : 4 } }), children] }));
}
/**
 * Augment `renderElement` method to support this element type
 */
function withRenderElement(renderElement) {
    const originalRenderElement = renderElement;
    return function renderElement(props) {
        if (props.element.type !== ELEMENT_TYPE)
            return originalRenderElement(props);
        return _jsx(Component, { ...props, element: props.element });
    };
}
export const ImageInline = {
    withEditor,
    withRenderElement,
};
