import create from "zustand";
/**
 * Creates an origin store using `zustand`.
 *
 * The purpose of this is to keep track of uploads and their progress but only
 * storing the key to the lookup in the Element itself. We do it this way
 * because we don't want to modify the Editor value during the upload or it
 * becomes part of the edit history.
 */
export const createUploadStore = ({ origins: origins = {}, } = { origins: {} }) => {
    return create((set, get) => ({
        uploads: origins,
        setUpload(id, origin) {
            set((state) => ({
                uploads: {
                    ...state.uploads,
                    [id]: origin,
                },
            }));
        },
        getUpload(id) {
            const origin = get().uploads[id];
            if (origin === undefined) {
                throw new Error(`Expected origin with id "${id}" but could not find it`);
            }
            return origin;
        },
    }));
};
