import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useSlateStatic, useSelected, useFocused } from "slate-react";
import { ImageControls } from "./image-controls";
import { useEffect, useState } from "react";
import { HostedImageContext } from "./hosted-image-context";
export * from "./status-bar";
export function RenderHostedImage({ attributes, element, children, }) {
    return (_jsxs("div", { ...attributes, style: { margin: "8px 0" }, children: [_jsx(HostedImage, { element: element, style: { borderRadius: element.width < 100 ? 0 : 4 } }), children] }));
}
/**
 * Adds a `boxShadow` around the Element when it is selected.
 */
export function useHighlightedStyle() {
    const selected = useSelected();
    const focused = useFocused();
    const highlighted = selected && focused;
    const boxShadow = highlighted ? "0 0 0 3px DodgerBlue" : "none";
    return { boxShadow };
}
/**
 * Takes an `element` (which it only needs for its `id`) and returns the
 * Upload object from it.
 */
export function useUpload(id) {
    const editor = useSlateStatic();
    /**
     * We call this even if it's not always required because it calls `useStore`
     * which is a React hook which means it needs to be called consistently.
     */
    const upload = editor.cloud.useStore((state) => state.uploads[id]);
    if (id.includes("/")) {
        return {
            status: "complete",
            url: id,
        };
    }
    else {
        return upload;
    }
}
// function getSizeFromElement(): {width: number, height: number} {
// }
export function HostedImage({ element, className, style, ...imageProps }) {
    const editor = useSlateStatic();
    const upload = useUpload(element.id);
    const [size, setSize] = useState({
        width: element.width,
        height: element.height,
    });
    useEffect(() => {
        setSize({ width: element.width, height: element.height });
    }, [element.width, element.height]);
    const highlightedStyle = useHighlightedStyle();
    const src = generateSrc({
        originUrl: upload.url,
        size: [element.width, element.height],
        maxSize: [element.maxWidth, element.maxHeight],
        isAnimated: element.isAnimated,
    });
    const srcSet = generateSrcSet({
        originUrl: upload.url,
        size: [element.width, element.height],
        maxSize: [element.maxWidth, element.maxHeight],
        isAnimated: element.isAnimated,
    });
    return (_jsx(HostedImageContext.Provider, { value: {
            editor,
            origin: upload,
            size,
            setSize,
        }, children: _jsx(ImageControls, { element: element, children: _jsx("img", { src: src, srcSet: srcSet, width: size.width, height: size.height, className: className, style: { ...highlightedStyle, ...style, display: "block" }, ...imageProps }) }) }));
}
function generateSrcSet({ originUrl, size, maxSize, isAnimated, }) {
    /**
     * If it's a url from `createObjectURL` then just return it
     */
    if (originUrl.startsWith("blob:"))
        return originUrl;
    const src1x = generateSrc({
        originUrl,
        size,
        maxSize,
        isAnimated,
    });
    const src2x = generateSrc({
        originUrl,
        size: [size[0] * 2, size[1] * 2],
        maxSize,
        isAnimated,
    });
    return `${src1x}, ${src2x} 2x`;
}
function generateSrc({ originUrl, size, maxSize, isAnimated, }) {
    /**
     * If it's a url from `createObjectURL` then just return it
     */
    if (originUrl.startsWith("blob:"))
        return originUrl;
    if (isAnimated || size[0] >= maxSize[0] || size[1] >= maxSize[1])
        return originUrl;
    return `${originUrl}?size=${size[0]}x${size[1]}`;
}
